var __extends = (this && this.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (Object.prototype.hasOwnProperty.call(b, p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
import * as React from 'react';
import { render, fireEvent, cleanup } from '@testing-library/react';
import { CollectorPortalFramework } from '../../../';
import { AmountSelector } from './';
var Container = /** @class */ (function (_super) {
    __extends(Container, _super);
    function Container() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.state = {
            value: 1000,
        };
        _this.handleChange = function (value) {
            _this.setState({ value: value });
        };
        return _this;
    }
    Container.prototype.render = function () {
        return (React.createElement(CollectorPortalFramework, null,
            React.createElement(AmountSelector, { currency: "SEK", min: 740, max: 1330, stepSize: 100, value: this.state.value, onChange: this.handleChange })));
    };
    return Container;
}(React.Component));
var setup = function () {
    var utils = render(React.createElement(Container, null));
    var increase = utils.getByTestId('increase');
    var decrease = utils.getByTestId('decrease');
    var input = utils.getByTestId('input');
    var slider = utils.getByTestId('slider');
    return __assign({ increase: increase,
        decrease: decrease,
        input: input,
        slider: slider }, utils);
};
afterEach(cleanup);
describe('The text input field', function () {
    test('It should show the value', function () {
        var input = setup().input;
        expect(input.value).toBe('1 000');
    });
    test('It should handle input changes', function () {
        var input = setup().input;
        expect(input.value).toBe('1 000');
        fireEvent.change(input, { target: { value: '1300' } });
        expect(input.value).toBe('1 300');
    });
    test('It should round inputted values on blur', function () {
        var input = setup().input;
        expect(input.value).toBe('1 000');
        fireEvent.change(input, { target: { value: '1250' } });
        fireEvent.blur(input);
        expect(input.value).toBe('1 300');
    });
    test('It should not be able to increase the value beyond the maximum', function () {
        var input = setup().input;
        expect(input.value).toBe('1 000');
        fireEvent.change(input, { target: { value: '1500' } });
        fireEvent.blur(input);
        expect(input.value).toBe('1 330');
    });
    test('It should not be able to decrease the value beyond the minimum', function () {
        var input = setup().input;
        expect(input.value).toBe('1 000');
        fireEvent.change(input, { target: { value: '600' } });
        fireEvent.blur(input);
        expect(input.value).toBe('740');
    });
});
describe('Increase/decrease buttons', function () {
    test('Clicks on the increase button should increase the value', function () {
        var _a = setup(), input = _a.input, increase = _a.increase;
        expect(input.value).toBe('1 000');
        fireEvent.click(increase);
        expect(input.value).toBe('1 100');
        fireEvent.click(increase);
        fireEvent.click(increase);
        expect(input.value).toBe('1 300');
    });
    test('Clicks on the decrease button should decrease the value', function () {
        var _a = setup(), input = _a.input, decrease = _a.decrease;
        expect(input.value).toBe('1 000');
        fireEvent.click(decrease);
        expect(input.value).toBe('900');
        fireEvent.click(decrease);
        expect(input.value).toBe('800');
    });
    test('The increase button should not be able to increase the value beyond the maximum', function () {
        var _a = setup(), input = _a.input, increase = _a.increase;
        expect(input.value).toBe('1 000');
        fireEvent.click(increase);
        fireEvent.click(increase);
        fireEvent.click(increase);
        fireEvent.click(increase);
        expect(input.value).toBe('1 330');
    });
    test('The decrease button should not be able to decrease the value beyond the minimum', function () {
        var _a = setup(), input = _a.input, decrease = _a.decrease;
        expect(input.value).toBe('1 000');
        fireEvent.click(decrease);
        fireEvent.click(decrease);
        fireEvent.click(decrease);
        expect(input.value).toBe('740');
    });
    test('It should be able to handle multiple mixed increase/decrease clicks', function () {
        var _a = setup(), input = _a.input, increase = _a.increase, decrease = _a.decrease;
        expect(input.value).toBe('1 000');
        fireEvent.click(increase);
        expect(input.value).toBe('1 100');
        fireEvent.click(decrease);
        fireEvent.click(increase);
        expect(input.value).toBe('1 100');
    });
});
describe('The range slider', function () {
    test('It should show the value', function () {
        var slider = setup().slider;
        expect(slider.value).toBe('1000');
    });
    test('It should handle input changes', function () {
        var slider = setup().slider;
        expect(slider.value).toBe('1000');
        fireEvent.change(slider, { target: { value: '1300' } });
        expect(slider.value).toBe('1300');
    });
});
//# sourceMappingURL=test.js.map