var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
import React, { forwardRef } from 'react';
import { withTheme } from 'emotion-theming';
import { lighten, darken } from 'polished';
import styled from '../../../';
import { SpinnerSvg } from '../Spinner';
// Loading is a html attribute and throws an error if we use it
var ButtonElement = styled.button(function (_a) {
    var size = _a.size, kind = _a.kind, loading = _a.buttonLoading, icon = _a.icon, theme = _a.theme;
    var styles = __assign(__assign({ fontFamily: 'inherit', whiteSpace: 'nowrap', textDecoration: 'none', textAlign: 'center', overflow: 'hidden', border: 0, borderRadius: theme.borderRadius.small, transition: 'background-color 100ms', pointerEvents: loading ? 'none' : undefined, position: loading ? 'relative' : 'initial', '&:disabled': {
            backgroundColor: theme.colors.disabledBackground,
            color: theme.colors.disabledText,
        }, '&:not(:disabled)': {
            cursor: 'pointer',
        }, '> div': {
            // all content but the spinner
            visibility: loading ? 'hidden' : undefined,
            display: icon ? 'flex' : undefined,
            alignItems: icon ? 'center' : undefined,
            justifyContent: icon ? 'center' : undefined,
        }, '> svg': {
            // the spinner
            display: loading ? 'flex' : 'none',
            position: 'absolute',
            top: '50%',
            left: '50%',
            transform: 'translate(-50%, -50%)',
        } }, getSizeStyles(theme, size)), getKindStyles(theme, kind));
    return styles;
});
var getKindStyles = function (theme, kind) {
    switch (kind) {
        case 'warn':
            return __assign(__assign({}, background(theme.colors.red)), { color: theme.colors.white });
        case 'secondary':
            return __assign(__assign({}, background(theme.colors.offWhite)), { color: theme.colors.black, '&:hover:not(:disabled)': {
                    backgroundColor: lighten(0.02, theme.colors.offWhite),
                }, '&:focus:not(:disabled)': {
                    backgroundColor: darken(0.02, theme.colors.offWhite),
                }, '&:active:not(:disabled)': {
                    backgroundColor: darken(0.04, theme.colors.offWhite),
                } });
        case 'text':
            return {
                backgroundColor: 'transparent',
                color: theme.colors.darkIndigo,
                minWidth: 0,
                paddingLeft: 12,
                paddingRight: 12,
                '&:hover:not(:disabled)': {
                    color: theme.colors.purple,
                },
                '&:active:not(:disabled)': {
                    color: theme.colors.purple,
                },
                '&:disabled': {
                    backgroundColor: 'transparent',
                },
            };
        case 'secondaryNegative':
            return __assign(__assign({}, background(theme.colors.white)), { color: theme.colors.black, '&:hover:not(:disabled)': {
                    backgroundColor: darken(0.02, theme.colors.white),
                }, '&:active:not(:disabled)': {
                    backgroundColor: darken(0.04, theme.colors.white),
                } });
        case 'success':
            return __assign(__assign({}, background(theme.colors.green)), { color: theme.colors.white });
        case 'cta':
            return __assign(__assign({}, background(theme.colors.purple)), { color: theme.colors.white });
        case 'primary':
        default:
            return __assign(__assign({}, background(theme.colors.lavender)), { color: theme.colors.purple, '&:hover:not(:disabled)': {
                    backgroundColor: lighten(0.01, theme.colors.lavender),
                }, '&:focus:not(:disabled)': {
                    backgroundColor: darken(0.01, theme.colors.lavender),
                }, '&:active:not(:disabled)': {
                    backgroundColor: darken(0.02, theme.colors.lavender),
                } });
    }
};
var getSizeStyles = function (theme, size) {
    var _a;
    var small = {
        fontSize: 14,
        lineHeight: 1.5,
        fontWeight: 300,
        paddingTop: 6,
        paddingBottom: 6,
        paddingLeft: 20,
        paddingRight: 20,
    };
    var medium = {
        fontSize: 16,
        lineHeight: 1.5,
        fontWeight: 300,
        minWidth: 120,
        paddingTop: 8,
        paddingBottom: 8,
        paddingLeft: 24,
        paddingRight: 24,
    };
    var large = {
        fontSize: 16,
        lineHeight: 1.5,
        fontWeight: 300,
        minWidth: 160,
        paddingLeft: 32,
        paddingRight: 32,
    };
    switch (size) {
        case 'small':
            return small;
        case 'large':
            return __assign(__assign({}, large), (_a = {}, _a[theme.breakpoints.mobileAndLower] = medium, _a));
        case 'medium':
        default:
            return medium;
    }
};
var background = function (backgroundColor) { return ({
    backgroundColor: backgroundColor,
    '&:hover:not(:disabled)': {
        backgroundColor: lighten(0.06, backgroundColor),
    },
    '&:focus:not(:disabled)': {
        backgroundColor: darken(0.08, backgroundColor),
    },
    '&:active:not(:disabled)': {
        backgroundColor: darken(0.1, backgroundColor),
    },
}); };
var IconContainer = styled.span(function (_a) {
    var _b;
    var iconAlignment = _a.iconAlignment, theme = _a.theme;
    return (_b = {
            maxWidth: '1.3em',
            maxHeight: '1.3em',
            marginRight: iconAlignment === 'start' ? '.5em' : 0,
            marginLeft: iconAlignment === 'end' ? '.5em' : 0,
            display: 'flex',
            justifyContent: 'center',
            alignItems: 'center'
        },
        _b[theme.breakpoints.mobileAndLower] = {
            maxWidth: '1.5em',
            maxHeight: '1.5em',
        },
        _b);
});
var getSpinnerColorByKind = function (theme, kind) {
    switch (kind) {
        case 'warn':
        case 'success':
        case 'cta':
            return theme.colors.white;
        case 'primary':
        case 'secondary':
        case 'secondaryNegative':
        case 'text':
        default:
            return theme.colors.purple;
    }
};
var _Button = forwardRef(function (_a, ref) {
    var theme = _a.theme, kind = _a.kind, loading = _a.loading, children = _a.children, icon = _a.icon, _b = _a.iconAlignment, iconAlignment = _b === void 0 ? 'start' : _b, size = _a.size, rest = __rest(_a, ["theme", "kind", "loading", "children", "icon", "iconAlignment", "size"]);
    return (React.createElement(ButtonElement, __assign({ "aria-busy": loading, buttonLoading: loading, icon: icon, size: size, kind: kind }, rest, { ref: ref }),
        React.createElement("div", null,
            icon && iconAlignment === 'start' && React.createElement(IconContainer, { iconAlignment: iconAlignment }, icon),
            children,
            icon && iconAlignment === 'end' && React.createElement(IconContainer, { iconAlignment: iconAlignment }, icon)),
        React.createElement(SpinnerSvg, { size: "75%", color: getSpinnerColorByKind(theme, kind) })));
});
export var Button = withTheme(_Button);
Button.displayName = 'Collector.Button';
//# sourceMappingURL=index.js.map