var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
import React, { useState, forwardRef } from 'react';
import Collapse from 'react-css-collapse';
import { ClassNames } from '@emotion/core';
import uniqid from 'uniqid';
import { Label } from '../Label';
import { Description } from './Description';
import { ViewOn, ViewOff } from './Icons';
import styled from '../../../';
var InputLabel = styled(Label)({
    display: 'flex',
    alignItems: 'center',
});
export var InputContainer = styled.div({
    maxWidth: 500,
    marginBottom: '1.25em',
});
var getBorderColor = function (indicateError, showAlertMessage, theme) {
    if (indicateError) {
        return showAlertMessage ? theme.colors.mediumGray : theme.colors.red;
    }
    return theme.colors.mediumGray;
};
export var InputField = styled.input(function (_a) {
    var indicateError = _a.indicateError, theme = _a.theme, showAlertMessage = _a.showAlertMessage;
    return ({
        font: 'inherit',
        color: 'inherit',
        width: '100%',
        border: '1px solid',
        marginRight: 'auto',
        padding: '7px 11px',
        boxSizing: 'border-box',
        appearance: 'none',
        boxShadow: 'none',
        transition: 'border-bottom-left-radius 150ms, border-bottom-right-radius 150ms',
        borderRadius: theme.borderRadius.small,
        borderColor: getBorderColor(indicateError, showAlertMessage, theme),
        borderBottomLeftRadius: showAlertMessage ? 0 : theme.borderRadius.small,
        borderBottomRightRadius: showAlertMessage ? 0 : theme.borderRadius.small,
        borderBottomColor: indicateError ? theme.colors.red : theme.colors.mediumGray,
        '&::-ms-reveal': {
            display: 'none',
        },
        '&::-ms-clear': {
            display: 'none',
        },
        '&:disabled': {
            opacity: 1,
            background: theme.colors.offWhite,
            borderColor: theme.colors.lightGray,
        },
    });
});
var Textarea = styled(InputField.withComponent('textarea'))(function (_a) {
    var showAlertMessage = _a.showAlertMessage;
    return ({
        resize: 'vertical',
        minHeight: 80,
        marginBottom: showAlertMessage ? -6 : undefined,
    });
});
var alertStyle = function (theme) { return ({
    fontWeight: 500,
    padding: 8,
    paddingLeft: 12,
    minHeight: 40,
    boxSizing: 'border-box',
    borderBottomLeftRadius: theme.borderRadius.small,
    borderBottomRightRadius: theme.borderRadius.small,
}); };
export var InputError = styled.div(function (_a) {
    var theme = _a.theme;
    return (__assign(__assign({}, alertStyle(theme)), { background: theme.colors.red, color: theme.colors.white }));
});
export var InputWarning = styled.div(function (_a) {
    var theme = _a.theme;
    return (__assign(__assign({}, alertStyle(theme)), { background: theme.colors.yellow, color: theme.colors.black }));
});
var IconSpan = styled.span(function (_a) {
    var show = _a.show;
    return ({
        height: 24,
        position: 'absolute',
        cursor: 'pointer',
        alignSelf: 'center',
        zIndex: 1,
        '> svg': {
            backgroundRepeat: 'no-repeat',
            backgroundPosition: 'center',
            width: 24,
            height: 24,
            marginRight: 8,
            marginTop: show ? 1 : 0,
        },
    });
});
var Field = styled.div(function (_a) {
    var togglePasswordWidth = _a.togglePasswordWidth;
    return ({
        width: togglePasswordWidth ? togglePasswordWidth : '100%',
        display: 'flex',
        justifyContent: 'flex-end',
        marginRight: 'auto',
        userSelect: 'none',
    });
});
export var Input = forwardRef(function (_a, ref) {
    var label = _a.label, togglePasswordWidth = _a.togglePasswordWidth, error = _a.error, warning = _a.warning, multiline = _a.multiline, description = _a.description, togglePassword = _a.togglePassword, onBlur = _a.onBlur, rest = __rest(_a, ["label", "togglePasswordWidth", "error", "warning", "multiline", "description", "togglePassword", "onBlur"]);
    var id = uniqid();
    var _b = useState(false), isDirty = _b[0], setIsDirty = _b[1];
    var _c = useState(false), show = _c[0], setShow = _c[1];
    Input.displayName = 'Collector.Input';
    var makeDirty = function (event) {
        if (onBlur) {
            onBlur(event);
        }
        setIsDirty(true);
    };
    var InputElement = multiline ? Textarea : InputField;
    var indicateError = Boolean(isDirty && error);
    var showErrorMessage = indicateError && typeof error !== 'boolean';
    var showWarningMessage = Boolean(isDirty && warning);
    return (React.createElement(ClassNames, null, function (_a) {
        var css = _a.css;
        return (React.createElement(InputContainer, null,
            label && (React.createElement(InputLabel, { htmlFor: id, error: indicateError },
                label,
                description && React.createElement(Description, { description: description }))),
            togglePassword ? (React.createElement(Field, { togglePasswordWidth: togglePasswordWidth },
                React.createElement(IconSpan, { show: show, onClick: function () { return setShow(!show); } }, show ? ViewOn : ViewOff),
                React.createElement(InputElement, __assign({ id: id, hasError: indicateError, "aria-invalid": indicateError, showAlertMessage: showErrorMessage || showWarningMessage, ref: ref }, rest, { onBlur: makeDirty, type: show ? 'text' : 'password' })))) : (React.createElement(InputElement, __assign({ id: id, hasError: indicateError, "aria-invalid": indicateError, showAlertMessage: showErrorMessage || showWarningMessage, ref: ref }, rest, { onBlur: makeDirty }))),
            React.createElement(Collapse, { isOpen: showErrorMessage, className: css({ transition: 'height 150ms' }) },
                React.createElement(InputError, null, error)),
            React.createElement(Collapse, { isOpen: showWarningMessage, className: css({ transition: 'height 150ms' }) },
                React.createElement(InputWarning, null, warning))));
    }));
});
//# sourceMappingURL=index.js.map