import * as React from 'react';
import styled from '../..';
var checkbox = function (color) {
    return "'data:image/svg+xml,%3Csvg xmlns=%22http://www.w3.org/2000/svg%22 viewBox=%220 0 9.862 8.198%22%3E%3Cpath fill=%22" + encodeURIComponent(color) + "%22 d=%22M8.972.188l-5.364 6.72L.883 3.659a.5.5 0 1 0-.766.642l3.117 3.718a.502.502 0 0 0 .383.179h.006a.502.502 0 0 0 .385-.188L9.753.812A.498.498 0 0 0 9.674.11a.498.498 0 0 0-.702.078z%22/%3E%3C/svg%3E%0A'";
};
var List = styled.ul({
    listStyleType: 'none',
    padding: 0,
    margin: 0,
    display: 'flex',
    justifyContent: 'stretch',
    textAlign: 'center',
});
// This breakpoint gives us an approximation of when the indicactor numbers no longer all fit on screen. 120 is the number, 280 is the main menu, 40 is the padding on each side
var progressIndicatorNumberBreakpoint = function (itemCount) { return "@media only screen and (max-width: " + (itemCount * 120 + 280 + 40 + 40) + "px)"; };
var Item = styled.li(function (_a) {
    var _b;
    var hasCompleted = _a.hasCompleted, active = _a.active, theme = _a.theme, itemCount = _a.itemCount;
    return ({
        display: 'flex',
        flexDirection: 'column',
        alignItems: 'center',
        position: 'relative',
        flex: '100% 1 1',
        '&:not(:first-child):before /* emotion-disable-server-rendering-unsafe-selector-warning-please-do-not-use-this-the-warning-exists-for-a-reason */': (_b = {
                content: '" "',
                width: '100%',
                height: 2,
                background: hasCompleted || active ? theme.colors.green : theme.colors.mediumGray,
                position: 'absolute',
                right: '50%',
                top: 22
            },
            _b[progressIndicatorNumberBreakpoint(itemCount)] = {
                top: 16,
            },
            _b[theme.breakpoints.mobileAndLower] = {
                top: 14,
            },
            _b),
    });
});
var Number = styled.div(function (_a) {
    var _b;
    var hasCompleted = _a.hasCompleted, active = _a.active, theme = _a.theme, itemCount = _a.itemCount;
    return (_b = {
            height: 40,
            width: 40,
            display: 'flex',
            justifyContent: 'center',
            alignItems: 'center',
            marginBottom: 8,
            border: "2px solid " + (hasCompleted || active ? theme.colors.green : theme.colors.mediumGray),
            borderRadius: 50,
            backgroundColor: active ? theme.colors.green : theme.colors.white,
            backgroundImage: hasCompleted ? "url(" + checkbox(theme.colors.green) + ")" : undefined,
            backgroundRepeat: 'no-repeat',
            backgroundPosition: 'center center',
            backgroundSize: 18,
            zIndex: 50,
            fontSize: 21,
            fontWeight: 500,
            color: active ? theme.colors.white : theme.colors.black
        },
        _b[progressIndicatorNumberBreakpoint(itemCount)] = {
            fontSize: 16,
            height: 30,
            width: 30,
            marginBottom: 0,
            backgroundSize: 14,
        },
        _b[theme.breakpoints.mobileAndLower] = {
            fontSize: 16,
            backgroundSize: 12,
            height: 25,
            width: 25,
        },
        _b);
});
var Label = styled.div(function (_a) {
    var _b;
    var itemCount = _a.itemCount;
    return (_b = {
            fontSize: 14,
            paddingLeft: 8,
            paddingRight: 8
        },
        _b[progressIndicatorNumberBreakpoint(itemCount)] = {
            display: 'none',
        },
        _b);
});
export var ProgressIndicator = function (_a) {
    var items = _a.items, active = _a.active;
    var hasCompleted = function (index) { return index < items.findIndex(function (x) { return x.key === active; }); };
    return (React.createElement(List, null, items.map(function (item, index) { return (React.createElement(Item, { key: item.key, hasCompleted: hasCompleted(index), active: item.key === active, onClick: hasCompleted(index) ? item.onClick : undefined, itemCount: items.length },
        React.createElement(Number, { itemCount: items.length, hasCompleted: hasCompleted(index), active: item.key === active }, !hasCompleted(index) && index + 1),
        React.createElement(Label, { itemCount: items.length }, item.label))); })));
};
//# sourceMappingURL=ProgressIndicator.js.map