import React, { useState } from 'react';
import { NavLink as RouterNavLink } from 'react-router-dom';
import Sidebar from 'react-sidebar';
import { withTheme } from 'emotion-theming';
import styled from '../../';
import { useWindowSize } from '../../hooks/use-window-size';
var Hamburger = function () { return (React.createElement("svg", { width: "24", height: "24", xmlns: "http://www.w3.org/2000/svg" },
    React.createElement("g", { fill: "currentColor", fillRule: "nonzero" },
        React.createElement("path", { d: "M3 13h18a1 1 0 0 0 0-2H3a1 1 0 0 0 0 2zM3 7h18a1 1 0 0 0 0-2H3a1 1 0 1 0 0 2zM3 19h18a1 1 0 0 0 0-2H3a1 1 0 0 0 0 2z" })))); };
var Cross = function () { return (React.createElement("svg", { width: "24", height: "24", xmlns: "http://www.w3.org/2000/svg" },
    React.createElement("g", { fill: "currentColor", fillRule: "nonzero" },
        React.createElement("path", { d: "M17.293 5.293l-12 12a1 1 0 0 0 1.414 1.414l12-12a1 1 0 1 0-1.414-1.414z" }),
        React.createElement("path", { d: "M5.293 6.707l12 12a1 1 0 0 0 1.414-1.414l-12-12a1 1 0 0 0-1.414 1.414z" })))); };
var Container = styled.div({
    display: 'flex',
    justifyContent: 'space-between',
    flexGrow: 1,
    flexDirection: 'column',
    height: '100%',
});
var IconButton = styled.button({
    color: 'inherit',
    cursor: 'pointer',
    backgroundColor: 'transparent',
    border: 0,
    position: 'absolute',
    top: 0,
    right: 0,
    width: 46,
    height: 46,
    display: 'flex',
    justifyContent: 'center',
    alignItems: 'center',
    transition: 'opacity 150ms',
    '&:focus': {
        outline: 'none',
    },
    '&:hover': {
        opacity: 0.5,
    },
});
var FooterContainer = styled.footer(function (_a) {
    var theme = _a.theme;
    return ({
        background: theme.colors.sidebarBlueDark,
        color: theme.colors.white,
        padding: 20,
    });
});
var MenuContainer = styled.nav({
    width: 280,
    margin: '40px 0',
});
var MenuList = styled.ul({
    listStyleType: 'none',
    margin: 0,
    padding: 0,
});
var MenuListItem = styled.li(function (_a) {
    var useMarginTop = _a.useMarginTop;
    return ({
        marginTop: useMarginTop ? 40 : 0,
        marginLeft: 12,
        marginRight: 12,
    });
});
var ExternalNavLink = styled.a(function (_a) {
    var theme = _a.theme;
    return ({
        display: 'flex',
        alignItems: 'center',
        padding: 12,
        color: 'inherit',
        textDecoration: 'none',
        transition: 'background-color 200ms, opacity 200ms',
        borderRadius: theme.borderRadius.small,
        '&:not(.active)': {
            opacity: 0.5,
        },
        '&:hover': {
            background: 'rgba(255, 255, 255, .1)',
        },
        '&.active:hover': {
            background: 'rgba(255, 255, 255, .05)',
        },
    });
});
var InternalNavLink = ExternalNavLink.withComponent(RouterNavLink);
var NavLinkLabel = styled.span({
    fontSize: 18,
    marginLeft: 16,
});
var NavLinkIcon = styled.div(function (_a) {
    var icon = _a.icon;
    return ({
        backgroundRepeat: 'no-repeat',
        backgroundPosition: 'top center',
        backgroundSize: '100%',
        width: 24,
        height: 24,
        backgroundImage: "url(" + icon + ")",
    });
});
var styles = function (theme) { return ({
    root: {
        position: 'absolute',
        top: 0,
        left: 0,
        right: 0,
        bottom: 0,
        overflow: 'hidden',
    },
    sidebar: {
        zIndex: 2,
        position: 'fixed',
        top: 0,
        bottom: 0,
        transition: 'transform 250ms ease-in-out',
        willChange: 'transform',
        overflowY: 'auto',
        WebkitOverflowScrolling: 'touch',
        background: theme.colors.sidebarBlue,
    },
    overlay: {
        zIndex: 1,
        position: 'fixed',
        top: 0,
        left: 0,
        right: 0,
        bottom: 0,
        opacity: 0,
        visibility: 'hidden',
        transition: 'opacity 250ms ease-in-out, visibility 250ms ease-in-out',
        backgroundColor: 'rgba(0, 0, 0, .3)',
    },
}); };
export var MainMenu = withTheme(function (_a) {
    var items = _a.items, menuFooter = _a.menuFooter, menuEvents = _a.menuEvents, theme = _a.theme;
    var windowSize = useWindowSize();
    var _b = useState(false), sidebarIsOpen = _b[0], setSidebarOpen = _b[1];
    var openSidebar = function () {
        if (menuEvents && menuEvents.onOpen) {
            menuEvents.onOpen();
        }
        setSidebarOpen(true);
    };
    var closeSidebar = function () {
        if (menuEvents && menuEvents.onClose) {
            menuEvents.onClose();
        }
        setSidebarOpen(false);
    };
    var menuItemClick = function (item) {
        if (item.onClick) {
            item.onClick(item);
        }
        setSidebarOpen(false);
    };
    var renderSidebar = function (includeCloseButton) {
        if (includeCloseButton === void 0) { includeCloseButton = false; }
        return (React.createElement(Container, null,
            includeCloseButton && (React.createElement(IconButton, { type: "button", onClick: closeSidebar },
                React.createElement(Cross, null))),
            React.createElement(MenuContainer, null,
                React.createElement(MenuList, null, items.map(function (item, i) { return (React.createElement(MenuListItem, { key: i, useMarginTop: item.useMarginTop }, item.externalLink ? (React.createElement(ExternalNavLink, { href: item.path, onClick: function () { return menuItemClick(item); } },
                    React.createElement(NavLinkIcon, { icon: item.icon }),
                    React.createElement(NavLinkLabel, null, item.label))) : (React.createElement(InternalNavLink, { to: item.path, onClick: function () { return menuItemClick(item); } },
                    React.createElement(NavLinkIcon, { icon: item.icon }),
                    React.createElement(NavLinkLabel, null, item.label))))); }))),
            menuFooter && React.createElement(FooterContainer, null, menuFooter)));
    };
    if (windowSize.innerWidth > 700) {
        return renderSidebar();
    }
    else {
        return (React.createElement(Sidebar, { sidebar: renderSidebar(true), open: sidebarIsOpen, pullRight: true, onSetOpen: setSidebarOpen, styles: styles(theme), touch: false },
            React.createElement(IconButton, { type: "button", onClick: openSidebar },
                React.createElement(Hamburger, null))));
    }
});
//# sourceMappingURL=MainMenu.js.map