export var createMenuTreeBy = function (menu, hostname, menuItemStartId) {
    if (menuItemStartId === void 0) { menuItemStartId = 0; }
    for (var key in menu) {
        var isSubmenu = menu[key] instanceof Array;
        if (isSubmenu) {
            menu[key].forEach(function (menuItem) {
                var urlHostname = getHostnameFrom(menuItem.url);
                var isSameHostname = (urlHostname === hostname);
                menuItem.id = ++menuItemStartId;
                if (isSameHostname) {
                    menuItem.url = transformUrlToPath(menuItem.url, hostname);
                }
                menuItem.hasExternalUrl = !isSameHostname;
                if (menuItem.subpages.length > 0) {
                    createMenuTreeBy(menuItem, hostname, menuItemStartId);
                }
            });
        }
    }
    return menu;
};
var transformUrlToPath = function (url, hostname) {
    var indexAt = url.indexOf(hostname);
    return url.substring(indexAt).substring(hostname.length);
};
var getHostnameFrom = function (url) {
    var hostname = url.indexOf('//') > -1 ? url.split('/')[2] : url.split('/')[0];
    hostname = hostname.split(':')[0];
    hostname = hostname.split('?')[0];
    return hostname;
};
export var traverse = function (menuItem, hostname, nodes) {
    if (menuItem.url === hostname) {
        return [];
    }
    else if (menuItem.hasOwnProperty('subpages') && menuItem.subpages.length > 0) {
        for (var i = 0; i < menuItem.subpages.length; i++) {
            var path = traverse(menuItem.subpages[i], hostname, nodes);
            if (path !== null) {
                nodes.push({
                    index: i,
                    url: menuItem.subpages[i].url,
                    id: menuItem.subpages[i].id,
                });
                path.unshift(i);
                return path;
            }
        }
    }
    return null;
};
export var getTraversedMenuNodes = function (menuItems, hostname, isDropdown, setActiveUrl) {
    if (isDropdown === void 0) { isDropdown = false; }
    var nodes = [];
    menuItems.forEach(function (menuItem, index) {
        var path = traverse(menuItem, hostname, nodes);
        if (path) {
            path.unshift(index);
            nodes.push({
                index: index,
                url: menuItem.url,
                id: menuItem.id,
            });
        }
    });
    nodes = nodes.reverse();
    if (setActiveUrl && nodes.length > 0 && !isDropdown) {
        setActiveUrl(nodes[nodes.length - 1].url);
    }
    if (isDropdown) {
        nodes.pop();
    }
    return nodes;
};
//# sourceMappingURL=portalMenu.js.map